# mlgauge

![Build](https://github.com/SuryaThiru/mlgauge/workflows/Python%20package/badge.svg)
![Formatting](https://github.com/SuryaThiru/mlgauge/workflows/Formatting/badge.svg)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
 [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

A simple wrapper to benchmark performance of machine learning methods across different datasets.
